'use strict';

var Analytics = require('@segment/analytics.js-core').constructor;
var integration = require('@segment/analytics.js-integration');
var sandbox = require('@segment/clear-env');
var tester = require('@segment/analytics.js-integration-tester');
var StripeRadar = require('../lib/');

describe('Stripe Radar', function() {
  var analytics;
  var stripeRadar;
  var options = {};

  beforeEach(function() {
    analytics = new Analytics();
    stripeRadar = new StripeRadar(options);
    analytics.use(StripeRadar);
    analytics.use(tester);
    analytics.add(stripeRadar);
  });

  afterEach(function() {
    analytics.restore();
    analytics.reset();
    stripeRadar.reset();
    sandbox();
  });

  it('should have the right settings', function() {
    analytics.compare(StripeRadar, integration('Stripe Radar')
      .tag('<script src="https://js.stripe.com/v2/"></script>'));
  });

  describe('before loading', function() {
    beforeEach(function() {
      analytics.stub(stripeRadar, 'load');
    });

    describe('#initialize', function() {
      it('should call load', function() {
        analytics.initialize();
        analytics.called(stripeRadar.load);
      });
    });
  });
});
